pub struct MemoryManager<P>where
P: MemoryProvider,{ /* private fields */ }Expand description
The memory manager handles page-level memory operations on top of a
MemoryProvider.
Implementations
Sourceimpl<P> MemoryManager<P>where
P: MemoryProvider,
impl<P> MemoryManager<P>where
P: MemoryProvider,
Sourcepub fn init(provider: P) -> Self
pub fn init(provider: P) -> Self
Initializes the memory manager and allocates the header and reserved pages.
Panics
Panics if the memory provider fails to initialize.
Sourcepub const fn schema_page(&self) -> Page
pub const fn schema_page(&self) -> Page
Returns the schema page.
Sourcepub const fn unclaimed_pages_page(&self) -> Page
pub const fn unclaimed_pages_page(&self) -> Page
Returns the unclaimed-pages ledger page.
Sourcepub fn pages_count(&self) -> u64
pub fn pages_count(&self) -> u64
Returns the total number of pages currently backed by the provider.