pub struct TableRegistryPage {
pub pages_list_page: Page,
pub free_segments_page: Page,
pub index_registry_page: Page,
pub autoincrement_registry_page: Option<Page>,
}Expand description
Data regarding the table registry page.
Fields
pages_list_page: PageThe page where the list of pages for this table is stored.
free_segments_page: PageThe page where the free segments for this table are stored.
index_registry_page: PageThe page where the index registry for this table is stored.
autoincrement_registry_page: Option<Page>The page where the autoincrement registry for this table is stored. Only used if the table has an autoincrement column.