Module table_registry

Module table_registry 

Structs

NextRecord
Represents the next record read by the TableReader.
TableReader
A reader for the table registry that allows reading records from memory.
TableRegistry
The table registry takes care of storing the records for each table, using the [FreeSegmentsLedger] and [PageLedger] to derive exactly where to read/write.