pub struct AutoincrementLedger { /* private fields */ }Expand description
Ledger for autoincrement values, used by tables with autoincrement columns.
Implementations
Sourceimpl AutoincrementLedger
impl AutoincrementLedger
Sourcepub fn init<TS>(page: Page, mm: &mut impl MemoryAccess) -> MemoryResult<Self>where
TS: TableSchema,
pub fn init<TS>(page: Page, mm: &mut impl MemoryAccess) -> MemoryResult<Self>where
TS: TableSchema,
Initialize the AutoincrementLedger for the given table schema, and write it to the given page.
Each autoincrement column in the table schema will be initialized in the registry with the appropriate zero value.
Sourcepub fn load(page: Page, mm: &mut impl MemoryAccess) -> MemoryResult<Self>
pub fn load(page: Page, mm: &mut impl MemoryAccess) -> MemoryResult<Self>
Load the AutoincrementLedger from the given page.
Sourcepub fn next(
&mut self,
column: &str,
mm: &mut impl MemoryAccess,
) -> MemoryResult<Value>
pub fn next( &mut self, column: &str, mm: &mut impl MemoryAccess, ) -> MemoryResult<Value>