IndexLedger

Struct IndexLedger 

pub struct IndexLedger { /* private fields */ }
The IndexLedger struct is responsible for managing and providing access to the indexes in the database.

Implementations

Source

impl IndexLedger

pub fn init( ledger_page: Page, indexes: &[IndexDef], mm: &mut impl MemoryAccess, ) -> MemoryResult<()>

Initializes the index ledger by creating an empty ledger page in memory and setting up the initial structure.

pub fn load(page: Page, mm: &mut impl MemoryAccess) -> MemoryResult<Self>

Load the page ledger from memory at the given Page.

pub fn insert<K>( &mut self, columns: &[&str], key: K, pointer: RecordAddress, mm: &mut impl MemoryAccess, ) -> MemoryResult<()>
where K: Encode + Ord,

Inserts a key-pointer pair into the index identified by columns.

pub fn search<K>( &self, columns: &[&str], key: &K, mm: &mut impl MemoryAccess, ) -> MemoryResult<Vec<RecordAddress>>
where K: Encode + Ord,

Looks up all pointers matching key in the index identified by columns.

pub fn delete<K>( &mut self, columns: &[&str], key: &K, pointer: RecordAddress, mm: &mut impl MemoryAccess, ) -> MemoryResult<()>
where K: Encode + Ord,

Deletes a specific key-pointer pair from the index identified by columns.

pub fn update<K>( &mut self, columns: &[&str], key: &K, old_pointer: RecordAddress, new_pointer: RecordAddress, mm: &mut impl MemoryAccess, ) -> MemoryResult<()>
where K: Encode + Ord,

Updates a specific key-pointer pair in the index identified by columns.

pub fn range_scan<K>( &self, columns: &[&str], start_key: &K, end_key: Option<&K>, mm: &mut impl MemoryAccess, ) -> MemoryResult<IndexTreeWalker<K>>
where K: Encode + Ord,

Opens a forward range scan on the index identified by columns.