pub struct RecordAddress {
pub page: Page,
pub offset: PageOffset,
}Expand description
The address of a record in the table registry, consisting of a page number and an offset within that page.
Fields
page: Pageoffset: PageOffsetImplementations
Sourceimpl RecordAddress
impl RecordAddress
Sourcepub fn new(page: Page, offset: PageOffset) -> Self
pub fn new(page: Page, offset: PageOffset) -> Self
Creates a new RecordAddress with the given page and offset.