TableReader

Struct TableReader 

pub struct TableReader<'a, E, MA>
where E: Encode, MA: MemoryAccess,
{ /* private fields */ }
A reader for the table registry that allows reading records from memory.

The table reader provides methods to read records from the table registry one by one, using the underlying [PageLedger] to locate the records in memory.

Implementations

Source

impl<'a, E, MA> TableReader<'a, E, MA>
where E: Encode, MA: MemoryAccess,

pub fn new(page_ledger: &'a PageLedger, mm: &'a MA) -> Self

Creates a new table reader starting from the beginning of the table registry.

pub fn try_next(&mut self) -> MemoryResult<Option<NextRecord<E>>>

Reads the next record from the table registry.