pub struct MemoryManager<P>where
P: MemoryProvider,{ /* private fields */ }Expand description
The memory manager handles page-level memory operations on top of a
MemoryProvider.
Implementations
Sourceimpl<P> MemoryManager<P>where
P: MemoryProvider,
impl<P> MemoryManager<P>where
P: MemoryProvider,
Sourcepub fn init(provider: P) -> Self
pub fn init(provider: P) -> Self
Initializes the memory manager and allocates the header and reserved pages.
Panics
Panics if the memory provider fails to initialize.
Sourcepub const fn schema_page(&self) -> Page
pub const fn schema_page(&self) -> Page
Returns the schema page.
Sourcepub fn write_at_raw(
&mut self,
page: Page,
offset: PageOffset,
buf: &[u8],
) -> MemoryResult<()>
pub fn write_at_raw( &mut self, page: Page, offset: PageOffset, buf: &[u8], ) -> MemoryResult<()>
Writes raw bytes at the specified page and offset, bypassing alignment and encoding checks.
This is used by the journal rollback path which already holds pre-captured byte buffers.