Structs
- Next
Record - Represents the next record read by the
TableReader. - Table
Reader - A reader for the table registry that allows reading records from memory.
- Table
Registry - The table registry takes care of storing the records for each table,
using the [
FreeSegmentsLedger] and [PageLedger] to derive exactly where to read/write.