AutoincrementLedger

Struct AutoincrementLedger 

pub struct AutoincrementLedger { /* private fields */ }
Ledger for autoincrement values, used by tables with autoincrement columns.

Implementations

Source

impl AutoincrementLedger

pub fn init<TS>(page: Page, mm: &mut impl MemoryAccess) -> MemoryResult<Self>
where TS: TableSchema,

Initialize the AutoincrementLedger for the given table schema, and write it to the given page.

Each autoincrement column in the table schema will be initialized in the registry with the appropriate zero value.

pub fn load(page: Page, mm: &mut impl MemoryAccess) -> MemoryResult<Self>

Load the AutoincrementLedger from the given page.

pub fn next( &mut self, column: &str, mm: &mut impl MemoryAccess, ) -> MemoryResult<Value>

Returns the next autoincrement Value for the given column, and persists the updated registry to memory.

Errors

Returns [MemoryError::AutoincrementOverflow] if the column has reached its maximum value.