pub struct TableReader<'a, E, MA>where
E: Encode,
MA: MemoryAccess,{ /* private fields */ }Expand description
A reader for the table registry that allows reading records from memory.
The table reader provides methods to read records from the table registry one by one,
using the underlying [PageLedger] to locate the records in memory.
Implementations
Sourceimpl<'a, E, MA> TableReader<'a, E, MA>where
E: Encode,
MA: MemoryAccess,
impl<'a, E, MA> TableReader<'a, E, MA>where
E: Encode,
MA: MemoryAccess,
Sourcepub fn new(page_ledger: &'a PageLedger, mm: &'a MA) -> Self
pub fn new(page_ledger: &'a PageLedger, mm: &'a MA) -> Self
Creates a new table reader starting from the beginning of the table registry.
Sourcepub fn try_next(&mut self) -> MemoryResult<Option<NextRecord<E>>>
pub fn try_next(&mut self) -> MemoryResult<Option<NextRecord<E>>>
Reads the next record from the table registry.